
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_border --
//   Returns the Border matrix of size n.
//   "The matrix has (n-2) eigenvalues at 1. Wilkinson (1965, pp 94-7) gives some
//   discussion of this property."
// Arguments, input
//  n : the size of the matrix to return
// Reference
//  J.C. Nash, Compact Numerical Methods for Computers: Linear
//  Algebra and Function Minimisation, second edition, Adam Hilger,
//  Bristol, 1990 (Appendix 1).
//
function m = makematrix_border ( n )
  m = zeros(n,n);
  for i = 1:n
  for j = 1:n
    if i==j then
      m(i,j) = 1
    elseif i<>n & j==n then
      m(i,j) = 2^(1-i)
    elseif j<>n & i==n then
      m(i,j) = 2^(1-j)
    end
  end
  end
endfunction

