
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_dingdong --
//   Returns the Ding Dong matrix of size n
//   "It is very stable under inversion by elimination
//   methods. Its eigenvalues have the property of clustering near p/2."
// Arguments, input
//  n : the size of the matrix to return
// Reference
//  J.C. Nash, Compact Numerical Methods for Computers: Linear
//  Algebra and Function Minimisation, second edition, Adam Hilger,
//  Bristol, 1990 (Appendix 1).
//
function a = makematrix_dingdong ( n )
  a = zeros(n,n);
  for i = 1: n
    for j = 1 : n
      a(i,j) = 0.5 / (n-i-j+1.5)
    end
  end
endfunction

