
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_hadamard --
//   Returns the Hadamard matrix of size n.
//   n is expected to be a power of 2.
// Arguments, input
//  n : the size of the matrix to return
// Reference
//  http://en.wikipedia.org/wiki/Hadamard_matrix
//
function a = makematrix_hadamard ( n )
  pow2n = log2(n);
  if ( n - 2^pow2n <>0 ) then
    errmsg = msprintf(gettext("%s: n is expected to be a power of 2."), "makematrix_hadamard");
    error(errmsg)
  end
  if n==1 then
    a = ones(1,1)
  else
    m = int(n/2)
    b = makematrix_hadamard(m)
    a = zeros(n,n)
    a(1:m,1:m) = b(1:m,1:m)
    a(1:m,m+1:n) = b(1:m,1:m)
    a(m+1:n,1:m) = b(1:m,1:m)
    a(m+1:n,m+1:n) = -b(1:m,1:m)
  end
endfunction

