
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_hankel --
//   Returns the Hankel matrix of size n.
// Arguments, input
//   n : the size of the matrix to return
//   x : the row vector of inputs
// Reference
//  http://en.wikipedia.org/wiki/Hankel_matrix
// Example:
//    n = 5, x = [1 2 3 4 5 6 7 8 9]
//
//    1  2  3  4  5
//    2  3  4  5  6
//    3  4  5  6  7
//    4  5  6  7  8
//    5  6  7  8  9
//
function m = makematrix_hankel ( n , x )
  m = zeros(n,n);
  nx1 = size(x,1)
  nx2 = size(x,2)
  if nx2 <> 2 * n - 1 then 
    error(sprintf("The second dimension of the input row vector x is %d and not %d as expected.",nx1,2*n-1))
  end
  if nx1 <> 1 then 
    error(sprintf("The first dimension of the input row vector x is %d and not 1 as expected.",nx1))
  end
  first = 1;
  last = n;
  for i = 1:n
    m(i,1:n) = x(first:last)
    first = first + 1
    last = last + 1
  end
endfunction

