
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_toeplitz --
//   Returns the toeplitz matrix of size n,
//   made with entries from x.
// Arguments, input
//  x : the input row vector
// References
//   http://en.wikipedia.org/wiki/Toeplitz_matrix
//
function a = makematrix_toeplitz ( x )
  n = size(x,2)
  a = zeros(n,n)
  // Set the values over the diagonal
  first = 1
  last = n
  for i = 1:n
    a(i,i:n) = x(first:last)
    last = last - 1
  end
  // Set the values under the diagonal (strictly
  first = 2
  last = 2
  for i = 2:n
    a(i,1:i-1) = x(first:-1:last)
    first = first + 1
  end
endfunction

