
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_wilkinsonm --
//   Returns the Wilkinson - matrix of size n.
// Arguments, input
//  n : the size of the matrix to return
// Reference
//  J.C. Nash, Compact Numerical Methods for Computers: Linear
//  Algebra and Function Minimisation, second edition, Adam Hilger,
//  Bristol, 1990 (Appendix 1).
//  J.H. Wilkinson, The Algebraic Eigenvalue Problem,
//  p. 308, "Close eigenvalues and small beta", W5-
//
function m = makematrix_wilkinsonm ( n )
  m = zeros(n,n);
  for i = 1:n
    m(i,i) = int(n/2)+1-i
  end
  for i = 1:n-1
    m(i,i+1) = 1.0
    m(i+1,i) = 1.0
  end
endfunction

