
// Copyright (C) 2008 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

computed = makematrix_magic ( 0 );
expected = [];
assert_equal ( computed , expected );

computed = makematrix_magic ( 1 );
expected = [1];
assert_equal ( computed , expected );

computed = makematrix_magic ( 2 );
expected = [
1     3
4     2
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 3 );
expected = [
8.    1.    6.  
3.    5.    7.
4.    9.    2.
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 4 );
expected = [
16.    2.     3.     13.  
5.     11.    10.    8.
9.     7.     6.     12.
4.     14.    15.    1.
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 5 );
expected = [
17.    24.    1.     8.     15.  
23.    5.     7.     14.    16.
4.     6.     13.    20.    22.
10.    12.    19.    21.    3.
11.    18.    25.    2.     9.
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 6 );
expected = [
    35.    1.     6.     26.    19.    24.  
    3.     32.    7.     21.    23.    25.  
    31.    9.     2.     22.    27.    20.  
    8.     28.    33.    17.    10.    15.  
    30.    5.     34.    12.    14.    16.  
    4.     36.    29.    13.    18.    11.  
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 7 );
expected = [
    30.    39.    48.    1.     10.    19.    28.  
    38.    47.    7.     9.     18.    27.    29.  
    46.    6.     8.     17.    26.    35.    37.  
    5.     14.    16.    25.    34.    36.    45.  
    13.    15.    24.    33.    42.    44.    4.   
    21.    23.    32.    41.    43.    3.     12.  
    22.    31.    40.    49.    2.     11.    20.  
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 8 );
expected = [
    64.    2.     3.     61.    60.    6.     7.     57.  
    9.     55.    54.    12.    13.    51.    50.    16.  
    17.    47.    46.    20.    21.    43.    42.    24.  
    40.    26.    27.    37.    36.    30.    31.    33.  
    32.    34.    35.    29.    28.    38.    39.    25.  
    41.    23.    22.    44.    45.    19.    18.    48.  
    49.    15.    14.    52.    53.    11.    10.    56.  
    8.     58.    59.    5.     4.     62.    63.    1.   
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 9 );
expected = [
    47.    58.    69.    80.    1.     12.    23.    34.    45.  
    57.    68.    79.    9.     11.    22.    33.    44.    46.  
    67.    78.    8.     10.    21.    32.    43.    54.    56.  
    77.    7.     18.    20.    31.    42.    53.    55.    66.  
    6.     17.    19.    30.    41.    52.    63.    65.    76.  
    16.    27.    29.    40.    51.    62.    64.    75.    5.   
    26.    28.    39.    50.    61.    72.    74.    4.     15.  
    36.    38.    49.    60.    71.    73.    3.     14.    25.  
    37.    48.    59.    70.    81.    2.     13.    24.    35.  
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 10 );
expected = [
    92.    99.    1.      8.     15.    67.    74.    51.    58.    40.  
    98.    80.    7.      14.    16.    73.    55.    57.    64.    41.  
    4.     81.    88.     20.    22.    54.    56.    63.    70.    47.  
    85.    87.    19.     21.    3.     60.    62.    69.    71.    28.  
    86.    93.    25.     2.     9.     61.    68.    75.    52.    34.  
    17.    24.    76.     83.    90.    42.    49.    26.    33.    65.  
    23.    5.     82.     89.    91.    48.    30.    32.    39.    66.  
    79.    6.     13.     95.    97.    29.    31.    38.    45.    72.  
    10.    12.    94.     96.    78.    35.    37.    44.    46.    53.  
    11.    18.    100.    77.    84.    36.    43.    50.    27.    59.  
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 11 );
expected = [
    68.     81.     94.     107.    120.    1.      14.     27.     40.     53.     66.   
    80.     93.     106.    119.    11.     13.     26.     39.     52.     65.     67.   
    92.     105.    118.    10.     12.     25.     38.     51.     64.     77.     79.   
    104.    117.    9.      22.     24.     37.     50.     63.     76.     78.     91.   
    116.    8.      21.     23.     36.     49.     62.     75.     88.     90.     103.  
    7.      20.     33.     35.     48.     61.     74.     87.     89.     102.    115.  
    19.     32.     34.     47.     60.     73.     86.     99.     101.    114.    6.    
    31.     44.     46.     59.     72.     85.     98.     100.    113.    5.      18.   
    43.     45.     58.     71.     84.     97.     110.    112.    4.      17.     30.   
    55.     57.     70.     83.     96.     109.    111.    3.      16.     29.     42.   
    56.     69.     82.     95.     108.    121.    2.      15.     28.     41.     54.   
];
assert_equal ( computed , expected );

computed = makematrix_magic ( 14 );
expected = [
    177.    186.    195.    1.      10.     19.     28.     128.    137.    146.    99.     108.    68.     77.   
    185.    194.    154.    9.      18.     27.     29.     136.    145.    105.    107.    116.    76.     78.   
    193.    153.    155.    17.     26.     35.     37.     144.    104.    106.    115.    124.    84.     86.   
    5.      161.    163.    172.    34.     36.     45.     103.    112.    114.    123.    132.    85.     94.   
    160.    162.    171.    33.     42.     44.     4.      111.    113.    122.    131.    140.    93.     53.   
    168.    170.    179.    41.     43.     3.      12.     119.    121.    130.    139.    141.    52.     61.   
    169.    178.    187.    49.     2.      11.     20.     120.    129.    138.    147.    100.    60.     69.   
    30.     39.     48.     148.    157.    166.    175.    79.     88.     97.     50.     59.     117.    126.  
    38.     47.     7.      156.    165.    174.    176.    87.     96.     56.     58.     67.     125.    127.  
    46.     6.      8.      164.    173.    182.    184.    95.     55.     57.     66.     75.     133.    135.  
    152.    14.     16.     25.     181.    183.    192.    54.     63.     65.     74.     83.     134.    143.  
    13.     15.     24.     180.    189.    191.    151.    62.     64.     73.     82.     91.     142.    102.  
    21.     23.     32.     188.    190.    150.    159.    70.     72.     81.     90.     92.     101.    110.  
    22.     31.     40.     196.    149.    158.    167.    71.     80.     89.     98.     51.     109.    118.  
];
assert_equal ( computed , expected );

